/**
 * @file
 * Hides iframes when functional cookies are not accepted.
 */

(function ($, Drupal, once) {
  'use strict';

  Drupal.behaviors.cookie_information_iframes = {
    attach: function (context, settings) {
      var blocked_iframes_category = settings.cookieinformation['block_iframes_category'] ? 'cookie_cat_' + settings.cookieinformation['block_iframes_category'] : 'cookie_cat_functional';
      var blocked_iframes_category_name = settings.cookieinformation['block_iframes_category_label'];
      $(once('cookieinformation-iframe', 'iframe', context)).each(function () {
        // Cookie information also generates an iframe element to the <head> section which we
        // don't want to block.
        // We also ignore iframe blocking if data-ignore-cookie-blocking is set
        // to true or if the iframe already has logic to handle the display with Cookie information
        // SDK.
        // @see https://support.cookieinformation.com/en/articles/5444629-third-party-cookie-blocking
        if (
          $(this).data('ignoreCookieBlocking') !== true &&
          $(this).attr('name') !== 'cookie-information-sharinglibrary-iframe' &&
          $(this).attr('data-consent-src') === undefined &&
          $(this).attr('data-category-consent') === undefined
        ) {
          $(this).attr('data-consent-src', $(this).attr('src'));
          $(this).attr('data-category-consent', blocked_iframes_category);
          $(this).removeAttr('src');

          $(this).after(
            '<div class="consent-placeholder" data-category="' +
              blocked_iframes_category +
              '">' +
              '<div class="consent-placeholder__content">' +
              '<h2 class="consent-placeholder__title">' +
              Drupal.t(
                'Unable to display content',
                {},
                { context: 'Cookie information' }
              ) +
              '</h2>' +
              '<p class="consent-placeholder__text">' +
              Drupal.t(
                "Unfortunately you are not able to view this content since you haven't accepted required cookie category @category.",
                { '@category': blocked_iframes_category_name },
                { context: 'Cookie information' }
              ) +
              '</p>' +
              '<button class="consent-placeholder__button" onClick="CookieConsent.renew()">' +
              Drupal.t(
                'Change settings',
                {},
                { context: 'Cookie information' }
              ) +
              '</button>' +
              '</div>' +
              '</div>'
          );
        }
      });
    },
  };
})(jQuery, Drupal, once);
